CHANGELOG
=========
* 0.3.2 (2023-05-31)
    * Fixed an issue with the setup.py breaking installation from pypi

* 0.3.1 (2023-02-28)
    * Fixed security issue in certifi

* 0.3.0 (2022-03-30)
    * Add support for request params in update document

* 0.2.1 (2021-11-29)
    * Fixed release

* 0.2.0 (2021-11-29)
    * An issue with the contact resource url was fixed

* 0.1.9 (2021-03-08)
    * Fixed header issue in delete methods

* 0.1.5 (2019-03-08)
    * Release
